#!/usr/bin/perl
use strict;
use warnings;

use Encode::JP;	# to import this module into an exe file which will be generated by PAR Packager

use POSIX qw(strftime);
use File::Spec::Functions qw(catfile);
use File::Path qw(mkpath);
use LWP::Simple;
use Getopt::Long qw(:config auto_help);
use Pod::Usage qw(pod2usage);

# Gets options and analyzes them.
my %options = (
	outdir   => '.',
	dirname  => 'livecam_%Y%m%d',
	filename => 'img_%Y%m%d_%H%M',
	interval => 1
);
Getopt::Long::GetOptions(\%options, qw(outdir=s dirname=s filename=s interval=i proxy=s useragent=s)) or pod2usage(2);
pod2usage(1) if ($options{help});

# Configures network settings. (Not checked whether it works...)
if ($options{proxy}) {
	$LWP::Simple::ua->proxy('http', $options{proxy});
}
if ($options{useragent}) {
	$LWP::Simple::ua->agent($options{useragent});
}

my $interval_sec = $options{interval} * 60;

my $next_time = time;
for (;;) {
	# Waits for the next time.
	my $cur_time = time;
	if ($cur_time < $next_time) {
		sleep 1;
		next;
	}

	# Makes the URL string and the download file path.
	my $url = 'http://livecamera.dqx.jp/shot_hl.jpg?' . $cur_time;
	my $dirname = catfile($options{outdir}, strftime($options{dirname}, localtime $cur_time));
	my $filename = strftime("$options{filename}.jpg", localtime $cur_time);
	my $outpath = catfile($dirname, $filename);

	# Makes a directory for images.
	unless (-d $dirname) {
		mkpath($dirname);
	}

	# Gets an image from the DQX Live Camera.
	printf "GET %s -> %s: ", $url, $outpath;
	my $rescode = getstore($url, $outpath);
	printf "%d %s\n", $rescode, is_success($rescode) ? 'OK' : 'NG';

	while ($next_time <= $cur_time) {
		$next_time += $interval_sec;
	}
}

__END__

=head1 NAME

dqxlivecam - Gets images periodically from the DRAGON QUEST X Live Camera.

=head1 SYNOPSIS

dqxlivecam [options]

  --outdir    A string of output directory for image files.
              Default is ".". (current directory)
  --dirname   A format string of directory name for image files.
              Default is "livecam_%Y%m%d". (Ex. "livecam_20130216")
  --filename  A format string for images' file name.
              (".jpg" is not included)
              Default is "img_%Y%m%d_%H%M". (Ex. "img_20130216_0558")
  --interval  A value of interval time in minutes.
  --proxy     A string of proxy host name.
  --useragent A string of user agent.
  --help      Print this message.

=cut
